===============
 API Reference
===============

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 2

    djcelery.app
    djcelery.common
    djcelery.views
    djcelery.urls
    djcelery.models
    djcelery.managers
    djcelery.loaders
    djcelery.schedulers
    djcelery.snapshot
    djcelery.backends.database
    djcelery.backends.cache
    djcelery.contrib.test_runner
    djcelery.humanize
    djcelery.db
    djcelery.utils
    djcelery.compat
